@@ -44,24 +44,25 @@ function(x, nar = 0, nma = 0, ar = rep(NA, max(nar, 1)), ma = rep(NA, max(nma,
 	if(missing(dtol))
 		dtol <- .Machine$double.eps^0.25
 	result <- .Fortran("fracdf",
-		as.double(x),
-		as.integer(n),
-		as.integer(M),
-		as.integer(nar),
-		as.integer(nma),
-		dtol = as.double(dtol),
-		drange = as.double(drange),
-		hood = double(1),
-		d = double(1),
-		ar = as.double(ar),
-		ma = as.double(ma),
-		w = double(lwork),
-		as.integer(lwork),
-		info = integer(1),
-		as.double(.Machine$double.xmin),
-		as.double(.Machine$double.xmax),
-		as.double(.Machine$double.neg.eps),
-		as.double(.Machine$double.eps))
+                           as.double(x),
+                           as.integer(n),
+                           as.integer(M),
+                           as.integer(nar),
+                           as.integer(nma),
+                           dtol = as.double(dtol),
+                           drange = as.double(drange),
+                           hood = double(1),
+                           d = double(1),
+                           ar = as.double(ar),
+                           ma = as.double(ma),
+                           w = double(lwork),
+                           as.integer(lwork),
+                           info = integer(1),
+                           as.double(.Machine$double.xmin),
+                           as.double(.Machine$double.xmax),
+                           as.double(.Machine$double.neg.eps),
+                           as.double(.Machine$double.eps),
+                           PACKAGE = "fracdiff")
 	if(result$info)
 		switch(result$info,
 			stop("insufficient workspace"),
@@ -71,23 +72,25 @@ function(x, nar = 0, nma = 0, ar = rep(NA, max(nar, 1)), ma = rep(NA, max(nma,
 			warning("optimization failure"),
 			warning("optimization limit reached"))
 	temp <- .Fortran("fdhpq",
-		as.double(x),
-		hess = double(npq1 * npq1),
-		as.integer(npq1),
-		double(lwork))
+                         as.double(x),
+                         hess = double(npq1 * npq1),
+                         as.integer(npq1),
+                         double(lwork),
+                         PACKAGE = "fracdiff")
 	hess <- temp$hess
 	temp <- .Fortran("fdcov",
-		as.double(x),
-		as.double(result$d),
-		h = as.double(if(missing(h)) -1 else h),
-		hd = double(npq1),
-		cov = as.double(hess),
-		as.integer(npq1),
-		cor = as.double(hess),
-		as.integer(npq1),
-		se = double(npq1),
-		double(lwork),
-		info = integer(1))
+                         as.double(x),
+                         as.double(result$d),
+                         h = as.double(if(missing(h)) -1 else h),
+                         hd = double(npq1),
+                         cov = as.double(hess),
+                         as.integer(npq1),
+                         cor = as.double(hess),
+                         as.integer(npq1),
+                         se = double(npq1),
+                         double(lwork),
+                         info = integer(1),
+                         PACKAGE = "fracdiff")
 	if(temp$info)
 		switch(temp$info,
 			warning("warning in gamma function"),
@@ -128,27 +131,31 @@ function(x, fracdiff.out, h)
 	lwork <- max(npq + 2 * (n + M), 3 * n + (n + 6) * npq + npq %/% 2 + 1, (
 		3 + 2 * npq1) * npq1 + 1)
 	.Fortran("fdcom",
-		as.integer(n),
-		as.integer(M),
-		as.integer(p),
-		as.integer(q),
-		as.double(fracdiff.out$log.likelihood),
-		as.double(.Machine$double.xmin),
-		as.double(.Machine$double.xmax),
-		as.double(.Machine$double.neg.eps),
-		as.double(.Machine$double.eps))
+                 as.integer(n),
+                 as.integer(M),
+                 as.integer(p),
+                 as.integer(q),
+                 as.double(fracdiff.out$log.likelihood),
+                 as.double(.Machine$double.xmin),
+                 as.double(.Machine$double.xmax),
+                 as.double(.Machine$double.neg.eps),
+                 as.double(.Machine$double.eps),
+                 PACKAGE = "fracdiff")
 	temp <- .Fortran("fdcov",
-		as.double(x),
-		as.double(fracdiff.out$d),
-		h = as.double(h),
-		hd = double(npq1),
-		cov = as.double(fracdiff.out$hessian.dpq),
-		as.integer(npq1),
-		cor = as.double(fracdiff.out$hessian.dpq),
-		as.integer(npq1),
-		se = double(npq1),
-		as.double(c(fracdiff.out$ma, fracdiff.out$ar, rep(0, lwork))),
-		info = integer(1))
+                         as.double(x),
+                         as.double(fracdiff.out$d),
+                         h = as.double(h),
+                         hd = double(npq1),
+                         cov = as.double(fracdiff.out$hessian.dpq),
+                         as.integer(npq1),
+                         cor = as.double(fracdiff.out$hessian.dpq),
+                         as.integer(npq1),
+                         se = double(npq1),
+                         as.double(c(fracdiff.out$ma,
+                                     fracdiff.out$ar,
+                                     rep(0, lwork))),
+                         info = integer(1),
+                         PACKAGE = "fracdiff")
 	if(temp$info)
 		switch(temp$info,
 			warning("warning in gamma function"),
@@ -177,19 +184,20 @@ function(n, ar, ma, d, mu = 0)
 	p <- length(ar)
 	q <- length(ma)
 	temp <- .Fortran("fdsim",
-		as.integer(n),
-		as.integer(p),
-		as.integer(q),
-		as.double(ar),
-		as.double(ma),
-		as.double(d),
-		as.double(mu),
-		as.double(rnorm(n + q)),
-		x = double(n + q),
-		as.double(.Machine$double.xmin),
-		as.double(.Machine$double.xmax),
-		as.double(.Machine$double.neg.eps),
-		as.double(.Machine$double.eps))$x[1:n]
+                         as.integer(n),
+                         as.integer(p),
+                         as.integer(q),
+                         as.double(ar),
+                         as.double(ma),
+                         as.double(d),
+                         as.double(mu),
+                         as.double(rnorm(n + q)),
+                         x = double(n + q),
+                         as.double(.Machine$double.xmin),
+                         as.double(.Machine$double.xmax),
+                         as.double(.Machine$double.neg.eps),
+                         as.double(.Machine$double.eps),
+                         PACKAGE = "fracdiff")$x[1:n]
 	list(series = temp, ar = ar, ma = ma, d = d, mu = mu)
 }
 
